# Accurate Benchmark

A python package for accurate benchmarking and speed comparisons

## Features

- Asynchronous Benchmarking
- Comparing asynchronous functions with synchronous ones
- Applying a decorator to any function to allow it to be benchmarked without creating a different variable for the function
- A tool for visualizing the benchmark results

## Requirements / Dependencies

- Python **3.13 or higher**
- [matplotlib>=3.10.8](https://pypi.org/project/matplotlib/)
- [numpy>=2.4.2](https://pypi.org/project/numpy/)
- [rich>=14.3.2](https://pypi.org/project/rich/)
- [scipy>=1.17.0](https://pypi.org/project/scipy/)
